static DH *get_dh512(void)
{
    static unsigned char dhp_512[] = {
        0xE1, 0x13, 0x9F, 0x76, 0x12, 0xF0, 0x7F, 0xF1, 0xD2, 0x5D,
        0xF1, 0x7A, 0x30, 0x9A, 0x66, 0x13, 0x40, 0x0F, 0xB1, 0x74,
        0x13, 0x90, 0xD2, 0x8C, 0x07, 0x6F, 0x86, 0x40, 0x8D, 0x07,
        0x26, 0x34, 0x88, 0x2F, 0xE3, 0x3D, 0x28, 0x0E, 0x9B, 0x79,
        0x94, 0xF2, 0xD3, 0xAB, 0xC9, 0x7C, 0x19, 0x93, 0x42, 0x25,
        0x40, 0x95, 0x5D, 0x72, 0x72, 0x12, 0x70, 0x2B, 0x18, 0x4E,
        0xE2, 0x9F, 0x3B, 0x57
    };
    static unsigned char dhg_512[] = {
        0x05
    };
    DH *dh = DH_new();
    BIGNUM *p, *g;

    if (dh == NULL)
        return NULL;
    p = BN_bin2bn(dhp_512, sizeof(dhp_512), NULL);
    g = BN_bin2bn(dhg_512, sizeof(dhg_512), NULL);
    if (p == NULL || g == NULL
            || !DH_set0_pqg(dh, p, NULL, g)) {
        DH_free(dh);
        BN_free(p);
        BN_free(g);
        return NULL;
    }
    return dh;
}
static DH *get_dh2048(void)
{
    static unsigned char dhp_2048[] = {
        0xD4, 0xAC, 0xDA, 0xFE, 0xCF, 0xBE, 0x2B, 0x46, 0xA6, 0x84,
        0x66, 0x69, 0xDC, 0x57, 0x1F, 0x6D, 0x50, 0x5A, 0xFA, 0x16,
        0x8B, 0x44, 0xA8, 0xBE, 0xA7, 0xE8, 0xE6, 0xE7, 0x0C, 0x65,
        0xE6, 0x0E, 0x5C, 0x50, 0xA1, 0xFC, 0xF5, 0xD0, 0x5E, 0xC7,
        0x3A, 0x0F, 0xB9, 0x40, 0x10, 0x1D, 0x6F, 0x08, 0xA7, 0xC9,
        0x80, 0x8F, 0x41, 0x6D, 0x1E, 0xCF, 0xDC, 0xBD, 0xFD, 0x7A,
        0x3D, 0x6B, 0xD8, 0x8B, 0xEA, 0xBE, 0xB2, 0xFC, 0xA3, 0xF7,
        0xC2, 0x5A, 0xC1, 0xDE, 0xC1, 0x31, 0x2D, 0x2E, 0x00, 0xD0,
        0x4F, 0x31, 0x44, 0x3E, 0xF3, 0x0D, 0x1C, 0x77, 0xF7, 0xD3,
        0x69, 0x39, 0xC0, 0x4B, 0x69, 0xF3, 0x37, 0xCF, 0x09, 0x04,
        0x60, 0xE7, 0xEE, 0x12, 0x6C, 0x16, 0x6B, 0x3B, 0x16, 0xA7,
        0x12, 0x63, 0x31, 0x25, 0xB2, 0x9A, 0x6D, 0xB6, 0x99, 0x94,
        0x54, 0xCD, 0x8F, 0xE5, 0x3D, 0xAE, 0x47, 0x4F, 0xF0, 0x3D,
        0x7B, 0xFB, 0xB9, 0x3E, 0x6E, 0x38, 0x60, 0xA4, 0x93, 0x46,
        0xEC, 0x07, 0x0E, 0xC2, 0x77, 0xE7, 0x32, 0x05, 0x5F, 0x56,
        0xD1, 0x36, 0x14, 0x09, 0x8A, 0x94, 0xA1, 0xB5, 0x63, 0xE8,
        0x57, 0x41, 0x73, 0xDB, 0x2E, 0xC4, 0x39, 0x4B, 0x16, 0x13,
        0xAF, 0x1E, 0xAF, 0xB9, 0xE6, 0xA8, 0x23, 0x6F, 0xAB, 0xD4,
        0x74, 0x57, 0x87, 0x57, 0x6A, 0x19, 0x8E, 0xAA, 0xB0, 0xE0,
        0xA6, 0x20, 0xAA, 0xFB, 0x21, 0x4D, 0x2D, 0x44, 0x87, 0x9A,
        0x03, 0xD5, 0x64, 0x15, 0x3D, 0x76, 0x66, 0x3D, 0xFB, 0x74,
        0xFE, 0x8F, 0x37, 0x1B, 0xB6, 0x7F, 0xAA, 0x4C, 0x5D, 0xBC,
        0xBF, 0x8A, 0x5B, 0xE9, 0xFA, 0x36, 0xEB, 0x12, 0x91, 0x96,
        0x28, 0x5D, 0x7F, 0x47, 0x7A, 0x7A, 0x3A, 0xDB, 0x23, 0x7A,
        0x41, 0x35, 0x86, 0x4B, 0x77, 0x3A, 0x07, 0x65, 0xFA, 0xC3,
        0xE0, 0x25, 0xBA, 0xE1, 0xF6, 0x83
    };
    static unsigned char dhg_2048[] = {
        0x05
    };
    DH *dh = DH_new();
    BIGNUM *p, *g;

    if (dh == NULL)
        return NULL;
    p = BN_bin2bn(dhp_2048, sizeof(dhp_2048), NULL);
    g = BN_bin2bn(dhg_2048, sizeof(dhg_2048), NULL);
    if (p == NULL || g == NULL
            || !DH_set0_pqg(dh, p, NULL, g)) {
        DH_free(dh);
        BN_free(p);
        BN_free(g);
        return NULL;
    }
    return dh;
}
